#
# spec file for package xfce4-panel-profiles
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xfce4-panel-profiles
Version:        1.0.14
Release:        1.4
Summary:        Simple application to manage Xfce panel layouts
License:        GPL-3.0-only
Group:          System/GUI/Other
URL:            https://git.xfce.org/apps/xfce4-panel-profiles/about/
#Git-Clone:     https://gitlab.xfce.org/apps/xfce4-panel-profiles.git
Source:         https://archive.xfce.org/src/apps/xfce4-panel-profiles/1.0/%{name}-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE Libxfce4ui.patch maurizio.galli@gmail.com -- OBS gets confused which typelib to require as dependency and we only need Libxfce4ui
Patch0:         Libxfce4ui.patch
BuildRequires:  appstream-glib
BuildRequires:  findutils
BuildRequires:  gobject-introspection
BuildRequires:  intltool
BuildRequires:  python3
BuildRequires:  python3-base
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  sed
BuildRequires:  xfce4-panel
Requires:       python3
Requires:       python3-base
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-psutil
Requires:       xfce4-panel
Recommends:     %{name}-lang
Recommends:     xfce4-panel-plugin-whiskermenu
BuildArch:      noarch

%description
Simple application to manage Xfce panel layouts.

This tool makes it possible to backup, restore, import, and export panel layouts.

%prep
%autosetup -p1

%build
# configure macro not working due to it using unsupported options
./configure \
    --prefix=%{_prefix} \
    --python=python3
%make_build

%install
# fix shebangs - convert to /usr/bin/python3
for dir in %{name}; do
    # find *.py, filter to files that contain bad shebangs
    find $dir -name '*.py' -type f -print0 \
        | xargs -0 grep -lE '^#!%{_bindir}/env' \
        | xargs sed -i '1s|#!%{_bindir}/env\>|#!%{_bindir}/python3|'

done
%make_install

# Remove not needed doc files
rm %{buildroot}%{_datadir}/doc/%{name}/{AUTHORS,COPYING,INSTALL,NEWS,README.md}

# Avoid rpmlint messages
chmod a-x %{buildroot}%{_datadir}/%{name}/%{name}/info.py
find %{buildroot}%{_datadir} \! -type d -print0 | xargs -0 -r chmod a-x
find %{buildroot}%{_datadir} -type d -print0 | xargs -0 -r chmod a+x
sed -i -e '/^Keywords=Configuration;User;/ d' %{buildroot}%{_datadir}/applications/*.desktop

%find_lang %{name}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files -f %{name}.lang
%doc AUTHORS NEWS README.md
%license COPYING
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/layouts
%dir %{_datadir}/%{name}/%{name}
%dir %{_datadir}/icons/hicolor/*
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%attr(644, root, root) %{_datadir}/%{name}/layouts/*
%{_datadir}/%{name}/%{name}/*.py
%attr(644, root, root) %{_datadir}/%{name}/%{name}/%{name}.glade
%attr(644, root, root) %{_datadir}/metainfo/org.xfce.PanelProfiles.appdata.xml
%{_datadir}/icons/hicolor/*/*
%attr(644, root, root) %{_mandir}/man1/xfce4-panel-profiles.1.gz

%changelog
* Tue Jun  6 2023 Manfred Hollstein <manfred.h@gmx.net>
- Refresh Libxfce4ui.patch again to ensure we require both
  typelib(Libxfce4ui) *and* typelib(Libxfce4util)
- Add Requires: python3-psutil
* Tue Jun  6 2023 Manfred Hollstein <manfred.h@gmx.net>
- Really fix files list and permissions of installed files
* Mon Jun  5 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.0.14
  * Save and restore rc-files
  * Add keywords to .desktop file (Fixes #9)
  * Properly filter filenames on startup
  * Ensure unique profile name and consistent filename
  * Pass correct length to GLib.KeyFile.load_from_data() (Fixes #20)
  * Open panel prefs dialog also on delete-event (Fixes #42)
  * configure: Use shell builtins instead of sed
  * Add missing translatable flags
  * Fix translations when $prefix != /usr
  * Add Unity layout
  * Use get_user_config_dir instead of get_home_dir (Fixes #38)
  * Show errors before saving profile to file
  * Ignore corrupted desktop-files on store Ignore empty launchers on
  store
  * Set correct desktop file name for translations
  * Makefile.in.in: Pass arguments to tar to make build reproducible
  regardless of user or umask
  * removed extra created link in makefile(#10)
  * Translation Updates
- Refresh Libxfce4ui.patch
- Fix files list and permissions of installed files
* Thu Jun 30 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add Git-Clone URL
* Mon Feb 22 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.0.13
  * Add Cupertino layout (gxo#apps/xfce4-panel-profiles#7)
  * Add Redmond 7 layout (gxo#apps/xfce4-panel-profiles#8)
  * Add Xfce 4.16 layout
  * Updated existing templates to support Xfce 4.16
  * Makefile.in.in: remove bashisms
  * Enabled exporting Whisker menu configuration
    (gxo#apps/xfce4-panel-profiles#11)
  * Translation Updates
* Thu Dec 31 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed Libxfce4ui.patch
* Wed Dec 30 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added Libxfce4ui.patch. OBS gets confused which typelib to require
  as dependency and we only need Libxfce4ui.
* Tue Dec 29 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.0.12
  * New Features:
  - New build option `--docdir` for documentation install path
  - New build option `--mandir` for manpage install path
  * General:
  - Manpage `xfce4-panel-profiles.1` is no longer gzipped
    (gxo#apps/xfce4-panel-profiles#5)
  * Bugs Fixed:
  - Release install error: incorrect README filename
    (gxo#apps/xfce4-panel-profiles#24)
- Updates from version 1.0.11
  * New Features
  - Add support for saving xfce4-whiskermenu's configuration file
  - Prefer CSD in XfceTitledDialog
  - Use XfceTitledDialog from libxfce4ui
  - Use Xfce's about dialog via libxfce4ui
  - Add new icons and use reverse DNS for icons and files
  - Open xfce4-panel on close button (bxo#16505)
  * General
  - Add new README.md over old README
  - Try the new and old libxfce4ui gir file name
  - Add basic GitLab pipeline
  - Make tarball creation reproducible
  * Bugs Fixed
  - Update openSUSE profile and fix build
  - Removed check for if the menu is installed. This would probably
    get in the way.
  - Use current branch in 'make distcheck'
  - Use configured appname instead of argv[0]
  - Fix typos in comments.
  * Updated translations
* Wed Jan 15 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.0.10
  * Add openSUSE profile
  * Add new error for invalid configuration files (bxo#15983)
  * 'Current Configuration' now pulls the current panel state instead of
    the state cached when the program starts (bxo#16114)
  * A cancellable warning is now displayed when applying configurations
    (bxo#14559)
  * Translations updates
- Removed patch openSUSE-profile.patch because merged upstream
* Sun Jul 28 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.0.9
  * Add Xfce 4.14 profile
  * Suppress deprecation warnings
  * Rename launchers to be more explicit
  * Rename Xubuntu releases to version numbers instead of codenames
  * Unversion gimp desktop file to work with any release
  * Fix KeyError when processing some layouts (bxo#14934)
  * Safely handle values that GLib cannot process (bxo#14597)
  * Translation updates
- Fixed and updated patch openSUSE-profile.patch
* Sun Dec  2 2018 Maurizio Galli <maurizio.galli@gmail.com>
- added openSUSE-profile.patch for openSUSE panel layout
- run spec cleaner
* Sun Dec  2 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Version 1.0.8 Initial Build
